@@ -1,7 +1,7 @@
 # zeropi.py
 #
 # This file is part of scqubits: a Python package for superconducting qubits,
-# arXiv:2107.08552 (2021). https://arxiv.org/abs/2107.08552
+# Quantum 5, 583 (2021). https://quantum-journal.org/papers/q-2021-11-17-583/
 #
 #    Copyright (c) 2019 and later, Jens Koch and Peter Groszkowski
 #    All rights reserved.
@@ -21,8 +21,7 @@ from matplotlib.axes import Axes
 from matplotlib.figure import Figure
 from numpy import ndarray
 from scipy import sparse
-from scipy.sparse.csc import csc_matrix
-from scipy.sparse.dia import dia_matrix
+from scipy.sparse import csc_matrix, dia_matrix
 
 import scqubits.core.central_dispatch as dispatch
 import scqubits.core.constants as constants
@@ -47,7 +46,7 @@ class NoisyZeroPi(NoisySystem):
     pass
 
 
-# -Symmetric 0-pi qubit, phi discretized, theta in charge basis---------------------------------------------------------
+# -Symmetric 0-pi qubit, phi discretized, theta in charge basis-------------------------
 
 
 class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
@@ -57,7 +56,7 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
     | [2] Dempster et al., Phys. Rev. B, 90, 094518 (2014). http://doi.org/10.1103/PhysRevB.90.094518
     | [3] Groszkowski et al., New J. Phys. 20, 043053 (2018). https://doi.org/10.1088/1367-2630/aab7cd
 
-    Zero-Pi qubit without coupling to the `zeta` mode, i.e., no disorder in `EC` and 
+    Zero-Pi qubit without coupling to the `zeta` mode, i.e., no disorder in `EC` and
     `EL`, see Eq. (4) in Groszkowski et al., New J. Phys. 20, 043053 (2018),
 
     .. math::
@@ -67,7 +66,7 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
                -2E_\text{J}\cos\theta\cos(\phi-\varphi_\text{ext}/2)+E_L\phi^2\\
           &\qquad +2E_\text{J} + E_J dE_J \sin\theta\sin(\phi-\phi_\text{ext}/2).
 
-    Formulation of the Hamiltonian matrix proceeds by discretization of the `phi` 
+    Formulation of the Hamiltonian matrix proceeds by discretization of the `phi`
     variable, and using charge basis for the `theta` variable.
 
     Parameters
@@ -79,7 +78,7 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
     ECJ:
         charging energy associated with the two junctions
     EC:
-        charging energy of the large shunting capacitances; set to `None` if `ECS` is 
+        charging energy of the large shunting capacitances; set to `None` if `ECS` is
         provided instead
     dEJ:
         relative disorder in EJ, i.e., (EJ1-EJ2)/EJavg
@@ -94,7 +93,7 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
     ncut:
         charge number cutoff for `n_theta`,  `n_theta = -ncut, ..., ncut`
     ECS:
-        total charging energy including large shunting capacitances and junction 
+        total charging energy including large shunting capacitances and junction
         capacitances; may be provided instead of EC
     truncated_dim:
         desired dimension of the truncated quantum system; expected: truncated_dim > 1
@@ -148,7 +147,6 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
         self.grid = grid
         self.ncut = ncut
         self.truncated_dim = truncated_dim
-        self._evec_dtype = np.complex_
 
         # _default_grid is for *theta*, needed for plotting wavefunction
         self._default_grid = discretization.Grid1d(-np.pi / 2, 3 * np.pi / 2, 200)
@@ -274,7 +272,7 @@ class ZeroPi(base.QubitBaseClass, serializers.Serializable, NoisyZeroPi):
         """
         return (
             -2.0 * self.EJ * np.cos(theta) * np.cos(phi - 2.0 * np.pi * self.flux / 2.0)
-            + self.EL * phi ** 2
+            + self.EL * phi**2
             + 2.0 * self.EJ
             + self.EJ
             * self.dEJ
